/* (C) 2022 YiRing, Inc. */
package com.yiring.app.constant.district;

import com.yiring.app.vo.KeyValueVo;
import java.util.ArrayList;
import java.util.List;
import lombok.Getter;

/**
 * 区域信息风险等级枚举
 * @author tml
 * @version 1.0
 * @date 2022/4/26 10:57
 */
public enum RiskGradeEnum {
    /**
     * 蓝色（安全）
     */
    BLUE(1, "蓝"),

    /**
     * 黄色（预警）
     */
    yellow(2, "黄"),

    /**
     * 红色（异常）
     */
    RED(3, "红");

    public static final int MIN = 1;

    public static final int MAX = 3;

    private static final List<KeyValueVo> LIST;

    static {
        LIST = new ArrayList<>();
        for (RiskGradeEnum item : values()) {
            LIST.add(KeyValueVo.builder().key(item.key).value(item.value).build());
        }
    }

    @Getter
    private final Integer key;

    @Getter
    private final String value;

    RiskGradeEnum(Integer key, String value) {
        this.key = key;
        this.value = value;
    }

    /**
     * 根据key获取value
     * @param key 等级key
     * @return 等级
     */
    public static String getByKey(Integer key) {
        if (key != null) {
            for (RiskGradeEnum item : values()) {
                if (item.key.equals(key)) {
                    return item.value;
                }
            }
        }
        return "未知等级";
    }

    /**
     * 获取所有等级
     * @return 所有等级集合
     */
    public static List<KeyValueVo> getAll() {
        return LIST;
    }
}
